@@ -15,7 +15,7 @@ use ExtUtils::MakeMaker qw($Verbose neatvalue);
 
 # If we make $VERSION an our variable parse_version() breaks
 use vars qw($VERSION);
-$VERSION = '7.02';
+$VERSION = '7.10';
 $VERSION = eval $VERSION;  ## no critic [BuiltinFunctions::ProhibitStringyEval]
 
 require ExtUtils::MM_Any;
@@ -192,9 +192,10 @@ sub cflags {
 	= @Config{qw(cc ccflags optimize shellflags)};
 
     # Perl 5.21.4 adds the (gcc) warning (-Wall ...) and std (-std=c89)
-    # flags to the %Config, and the modules in the core can be built
-    # with those.
-    my @ccextraflags = qw(ccwarnflags ccstdflags);
+    # flags to the %Config, and the modules in the core should be built
+    # with the warning flags, but NOT the -std=c89 flags (the latter
+    # would break using any system header files that are strict C99).
+    my @ccextraflags = qw(ccwarnflags);
     if ($ENV{PERL_CORE}) {
       for my $x (@ccextraflags) {
         if (exists $Config{$x}) {
@@ -675,13 +676,13 @@ Defines a check in target for RCS.
 
 sub dist_ci {
     my($self) = shift;
-    return q{
-ci :
-	$(PERLRUN) "-MExtUtils::Manifest=maniread" \\
-	  -e "@all = keys %{ maniread() };" \\
-	  -e "print(qq{Executing $(CI) @all\n}); system(qq{$(CI) @all});" \\
-	  -e "print(qq{Executing $(RCS_LABEL) ...\n}); system(qq{$(RCS_LABEL) @all});"
-};
+    return sprintf "ci :\n\t%s\n", $self->oneliner(<<'EOF', [qw(-MExtUtils::Manifest=maniread)]);
+@all = sort keys %{ maniread() };
+print(qq{Executing $(CI) @all\n});
+system(qq{$(CI) @all}) == 0 or die $!;
+print(qq{Executing $(RCS_LABEL) ...\n});
+system(qq{$(RCS_LABEL) @all}) == 0 or die $!;
+EOF
 }
 
 =item dist_core (o)
