@@ -166,11 +166,8 @@ d_fpclassl='undef'
 d_fpgetround='undef'
 d_fpos64_t='undef'
 d_frexpl='undef'
-d_fs_data_s='undef'
 d_fseeko='undef'
 d_fsetpos='define'
-d_fstatfs='undef'
-d_fstatvfs='undef'
 d_fsync='undef'
 d_ftello='undef'
 d_ftime='undef'
@@ -181,7 +178,6 @@ d_gdbmndbm_h_uses_prototypes='undef'
 d_getaddrinfo='undef'
 d_getcwd='define'
 d_getespwnam='undef'
-d_getfsstat='undef'
 d_getgrent='undef'
 d_getgrent_r='undef'
 d_getgrgid_r='undef'
@@ -198,8 +194,6 @@ d_gethostprotos='define'
 d_getitimer='undef'
 d_getlogin='undef'
 d_getlogin_r='undef'
-d_getmnt='undef'
-d_getmntent='undef'
 d_getnameinfo='undef'
 d_getnbyaddr='undef'
 d_getnbyname='undef'
@@ -241,7 +235,6 @@ d_gmtime64='undef'
 d_gmtime_r='undef'
 d_gnulibc='undef'
 d_grpasswd='undef'
-d_hasmntopt='undef'
 d_htonl='define'
 d_hypot='undef'
 d_ilogb='undef'
@@ -469,10 +462,7 @@ d_sresgproto='undef'
 d_sresuproto='undef'
 d_stat='define'
 d_statblks='undef'
-d_statfs_f_flags='undef'
-d_statfs_s='undef'
 d_static_inline='undef'
-d_statvfs='undef'
 d_stdio_cnt_lval='undef'
 d_stdio_ptr_lval='undef'
 d_stdio_ptr_lval_nochange_cnt='undef'
@@ -531,7 +521,6 @@ d_unordered='undef'
 d_unsetenv='undef'
 d_usleep='define'
 d_usleepproto='undef'
-d_ustat='undef'
 d_vendorarch='undef'
 d_vendorbin='undef'
 d_vendorlib='undef'
@@ -651,7 +640,6 @@ i_malloc='undef'
 i_mallocmalloc='undef'
 i_math='define'
 i_memory='undef'
-i_mntent='undef'
 i_ndbm='undef'
 i_netdb='define'
 i_neterrno='undef'
@@ -682,7 +670,6 @@ i_sysioctl='define'
 i_syslog='undef'
 i_sysmman='undef'
 i_sysmode='undef'
-i_sysmount='undef'
 i_sysndir='undef'
 i_sysparam='undef'
 i_syspoll='undef'
@@ -691,8 +678,6 @@ i_syssecrt='undef'
 i_sysselct='undef'
 i_syssockio='undef'
 i_sysstat='define'
-i_sysstatfs='undef'
-i_sysstatvfs='undef'
 i_systime='define'
 i_systimek='undef'
 i_systimes='define'
@@ -700,13 +685,11 @@ i_systypes='define'
 i_sysuio='undef'
 i_sysun='undef'
 i_sysutsname='undef'
-i_sysvfs='undef'
 i_syswait='undef'
 i_termio='undef'
 i_termios='undef'
 i_time='define'
 i_unistd='define'
-i_ustat='undef'
 i_utime='undef'
 i_values='undef'
 i_varargs='undef'
